import { ZodObject } from 'zod';
import { ConnectFormProps } from './ConnectForm.js';

export type ConnectedConnectFormProps<Schema extends ZodObject<any>> = Omit<ConnectFormProps<Schema>, "defaultValues" | "onSubmit"> & {
    connect: {
        getConfig: {
            useQuery: Function;
        };
        upsertConfig: {
            useMutation: Function;
        };
    };
};
/**
 * ConnectedConnectForm is a Form variant that accepts a schema and automatically constructs a form
 * that collects all the inputs defined in your schema as well as several default Connect fields.
 *
 * When provided with the pre-built tRPC methods installed by {@link createConnectRouter}
 * the form will populate a user's existing configuration values on load and automatically handle
 * form submission.
 *
 * @param props
 * @see createConnectRouter
 */
export declare const ConnectedConnectForm: <Schema extends ZodObject<any>>({ connect: _connect, ...otherProps }: ConnectedConnectFormProps<Schema>) => import("react").JSX.Element;
//# sourceMappingURL=ConnectedConnectForm.d.ts.map